Learn R Programming

docorator (version 0.5.2)

hf_to_gt: Apply headers and footnotes to gt object

Description

Pulls headers and footnotes from the docorator object and applies them to the gt object Note: this function is only for use by downstream tools and is not intended for general users

Usage

hf_to_gt(x)

Value

gt object (either tbl or group)

Arguments

x

a docorator object

Examples

Run this code
docorator <- gt::exibble |>
  gt::gt()|>
  as_docorator(
  display_name = "my_tbl",
  header = fancyhead(
  fancyrow(left = "Protocol: 12345", right = doc_pagenum()),
  fancyrow(center = "Demographic Summary")
  ),
  footer = NULL,
  save_object = FALSE)

hf_to_gt(docorator)

Run the code above in your browser using DataLab